@@ -228,6 +228,10 @@ class MovieWindow(hildon.StackableWindow):
         return strContent                              
 
 class Window(hildon.StackableWindow):
+    #Pointer to closest show and pannable area for scrolling later
+    show_pointer = None
+    pannable_area = None
+
     def __init__(self, url, id):
         gtk.Window.__init__(self)        
         self.connect("delete_event", self.close_window)
@@ -245,9 +249,11 @@ class Window(hildon.StackableWindow):
         
         #Make pannable area with vbox (we add later hbox into it)
         self.vbox = gtk.VBox()
-        pa = hildon.PannableArea()
-        pa.add_with_viewport(self.vbox)
-        self.add(pa)
+        global pannable_area
+        pannable_area = hildon.PannableArea()
+        pannable_area.add_with_viewport(self.vbox)
+        pannable_area.connect_after('map', self.show_scroll)
+        self.add(pannable_area)
         #Showing window
         self.show_all()
                 
@@ -327,13 +333,27 @@ class Window(hildon.StackableWindow):
             temp = temp.ljust(maxwidth + (maxwidth - len(item)))
             self.auditorium[index] = temp
             #print '%s - %d - %d' % (temp, len(temp), len(item))
-        
+
+    def show_scroll(self, widget):
+        #Scroll to next show
+        global pannable_area
+        global show_pointer
+        pannable_area.scroll_to_child(show_pointer)
+        #print 'scrolled'
+                
     def draw_schedule(self, args):
+        global show_pointer
         #print "drawing buttons"
         vbox_left = gtk.VBox()
         vbox_right = gtk.VBox()
-        lbl_header = gtk.Label("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")")
-        self.vbox.pack_start(lbl_header)
+        #lbl_header = gtk.Label("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")")
+        #self.vbox.pack_start(lbl_header)
+        butt_header = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        butt_header.set_text("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")", "Press here for scrolling to current time")
+        butt_header.set_value_alignment(.5, 1)
+        butt_header.connect("clicked", self.show_scroll)
+        self.vbox.pack_start(butt_header)
+        
         for index, item in enumerate(self.originalname):
              #If we are closing window then abort
              if (self.exiting): break
@@ -347,6 +367,9 @@ class Window(hildon.StackableWindow):
              butt_time.set_text(self.showtime[index], "")
              butt_time.connect("clicked", self.open_url, self.showlink[index])
              #butt_time.set_sensitive(1)
+             #Save last started show to pointer
+             if (self.showtime[index] < time.strftime("%H:%M", time.localtime())): 
+                 show_pointer = butt_time
 
              #butt_rating = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL)
              #butt_rating.add(self.ratingimages[index])
@@ -538,8 +561,8 @@ class MainWindow(hildon.StackableWindow):
         dialog.set_transient_for(self)
         dialog.set_title("Preferences")
         btn_options = hildon.PickerButton(gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        btn_options.set_title("Change Cinema")
-        #btn_options.set_alignment(.0, .5, 1., 0.)
+        btn_options.set_title("Change Company")
+        btn_options.set_value_alignment(.5, 1)
         selector = self.create_cinema_selector()
         btn_options.set_selector(selector)
         btn_options.connect("value-changed", self.value_changed)
